---
title: <span class="badge object-type-scalar"></span> Exposure
---
# <span class="badge object-type-scalar"></span> Exposure

Radiation: Exposure (C/kg)

## Definition

```python
# Radiation: Exposure (C/kg)
Exposure: typing.Literal["radexpckg"] = "radexpckg"
```
